@@ -155,9 +155,15 @@ while (<FILE>) {
 			# Order is important as we need to handle hashes refs before simple vars
 			eval { $tmp =~ s/(\$\w+-\>\{\'\w+\'\})/$1/eeg };
 			eval { $tmp =~ s/(\$\w+)/$1/eeg };
+			if (($s =~ /^PBDESC$/) && ($line =~ /^ PBDESC/)) {
+				# if on debian, we need to preserve the space before each desc line
+				pb_log(3,"*** DEBIAN CASE ADDING SPACE ***\n");
+				$tmp =~ s/\$\//\$\/ /g;
+				pb_log(3,"*** tmp:$tmp ***\n");
+			}
 			eval { $tmp =~ s/(\$\/)/$1/eeg };
-		# special case for ChangeLog only for pb
 		} elsif (($s =~ /^PBLOG$/) && ($line =~ /^PBLOG$/)) {
+			# special case for ChangeLog only for pb
 			pb_log(3,"DEBUG filtering PBLOG\n");
 			pb_changelog($pb, \*DEST, $tmp);
 			$tmp = "";
